# Tutorials

Each tutorial below is presented in a Jupyter notebook. You can view the executed notebooks here
in the documentation, view the raw notebooks on GitHub, or interactively run them in your web
browser using Binder by clicking the respective links below.

## Functionality Overview

[View Notebook on GitHub](https://github.com/KingsburyLab/pyEQL/tree/main/docs/examples/pyeql_demo.ipynb) | Try Interactive Notebook on Binder [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/KingsburyLab/pyEQL/main?labpath=docs%2Fexamples%2Fpyeql_demo.ipynb)

```{toctree}
:maxdepth: 1
examples/pyeql_demo
```

## Calculating Osmotic Pressure

[View Notebook on GitHub](https://github.com/KingsburyLab/pyEQL/tree/main/docs/examples/pyeql_tutorial_osmotic_pressure.ipynb) | Try Interactive Notebook on Binder [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/KingsburyLab/pyEQL/main?labpath=docs%2Fexamples%2Fpyeql_tutorial_osmotic_pressure.ipynb)

```{toctree}
:maxdepth: 2
examples/pyeql_tutorial_osmotic_pressure
```

## Accessing the Property Database

[View Notebook on GitHub](https://github.com/KingsburyLab/pyEQL/tree/main/docs/examples/pyeql_tutorial_database.ipynb) | Try Interactive Notebook on Binder [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/KingsburyLab/pyEQL/main?labpath=docs%2Fexamples%2Fpyeql_tutorial_osmotic_pressure.ipynb)

```{toctree}
:maxdepth: 2
examples/pyeql_tutorial_database
```
